pub enum Shutdown {
Read,
Write,
Both,
}Expand description
Possible values which can be passed to the TcpStream::shutdown method.
Variants
Read
The reading portion of the TcpStream should be shut down.
Write
The writing portion of the TcpStream should be shut down.
All currently blocked and future writes will return an error.
Both
Both the reading and the writing portions of the TcpStream should be shut down.
See Shutdown::Read and Shutdown::Write for more information.